canAuthenticate method
- @Deprecated('Use PasskeyAvailability.isAvailable instead. ' 'This method will be removed in a future release.')
Returns true only if passkeys are supported by the platform.
Implementation
@Deprecated(
'Use PasskeyAvailability.isAvailable instead. '
'This method will be removed in a future release.',
)
Future<bool> canAuthenticate() {
return _platform.canAuthenticate();
}