signalAllAcceptedCredentials method
Signals to the platform the complete set of credentials that the relying party still accepts for a user.
Where supported any credentials not contained in SignalAllAcceptedCredentialsRequestType.allAcceptedCredentialIds are pruned from the passkey picker.
This is a best-effort hint. It is only acted upon on Android (with a
Credential Manager provider that supports the Signal API), iOS 26.2 and
later, macOS 26.2 and later, and browsers that expose
PublicKeyCredential.signalAllAcceptedCredentials. On every other
platform or OS version, including older iOS and macOS releases, the call
is a no-op.
Implementation
@override
Future<void> signalAllAcceptedCredentials(
SignalAllAcceptedCredentialsRequestType request,
) async {
try {
_isValidUserID(request.userId);
for (final credentialId in request.allAcceptedCredentialIds) {
_isValidCredentialID(credentialId);
}
await _platform.signalAllAcceptedCredentials(request);
} on PlatformException catch (e, stackTrace) {
_mapSignalException(e, stackTrace);
}
}