DomainNotAssociatedException class

Thrown when the relying party domain is not associated with the app.

Implemented types

Constructors

DomainNotAssociatedException(String? message)
Constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
The error message describing the association failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited