types library
Classes
- AuthenticateRequestType
- The AuthenticateRequestType is used to create an authentication request and send it to the platform.
- AuthenticateResponseType
- The response returned by the platform after an authentication flow.
- AuthenticatorSelectionType
- Describes the relying party's requirements for the authenticator that should be used during a credential operation.
- AvailabilityType
- The base class for platform-specific availability information.
- AvailabilityTypeAndroid
- Represents the availability information specific to Android platforms.
- AvailabilityTypeIOS
- Represents the availability information specific to iOS platforms.
- AvailabilityTypeWeb
- Represents the availability information specific to web platforms.
- AvailabilityTypeWindows
- Represents the availability information specific to Windows platforms.
- Checkpoint
- CredentialType
- The CredentialType class wraps the data of a credential it can be used to explicitly exclude or allow credentials.
- ExceptionInfo
- PasskeyAuthenticatorInterface
- Interface for authenticators that perform the platform WebAuthn ceremonies.
- PasskeysDoctor
- PubKeyCredParamType
- The PubKeyCredParamType class wraps the data of a public key credential parameter. It is used to specify the type and algorithm of the public key credential that is being requested.
- RegisterRequestType
- The RegisterRequestType is used to create a registration request and send it to the platform.
- RegisterResponseType
- The response returned by the platform after a registration flow.
- RelyingPartyType
- The RelyingPartyType class wraps the data of a relying party. It is used to identify the party that is requesting authentication.
- Result
- SignalAllAcceptedCredentialsRequestType
- The SignalAllAcceptedCredentialsRequestType is used to tell the platform the complete set of credential IDs that the relying party still accepts for a given user, so that any others can be pruned from the credential picker.
- SignalUnknownCredentialRequestType
- The SignalUnknownCredentialRequestType is used to tell the platform that a credential is no longer recognized by the relying party, so that it can be removed from the credential picker and autofill suggestions.
- UserType
- The UserType class wraps the data of a user..
Enums
- CheckpointType
- MediationType
- Defines how user mediation (interaction) should be handled during credential operations.
Constants
-
exceptionInfos
→ const Map<
String, ExceptionInfo>
Functions
-
getExceptionInfo(
PlatformException error, List< Checkpoint> checkpoints) → Future<ExceptionInfo>
Exceptions / Errors
- AuthenticatorException
- Used as a base exception for all authenticator exceptions thrown by this package.
- DeviceNotSupportedException
- This exception is thrown when the device does not support passkeys. Suggestions:
- DoctorException
- DomainNotAssociatedException
- Thrown when the relying party domain is not associated with the app.
- ExcludeCredentialsCanNotBeRegisteredException
- Thrown when the user tries to register but one of the excluded credentials matches an existing one on your local device.
- MalformedBase64Url
- This exception is thrown when a string is not a valid Base64URL encoded string.
- MalformedBase64UrlChallenge
- This exception is thrown when the user tries to login or register but the challenge is not a valid Base64URL encoded string.
- MalformedBase64UrlCredentialID
- This exception is thrown when the user tries to login or register but the credential ID is not a valid Base64URL encoded string.
- MalformedBase64UrlUserID
- This exception is thrown when the user tries to login or register but the user ID is not a valid Base64URL encoded string.
- MissingGoogleSignInException
- This exception is thrown when the user tries to login but is not logged in to a Google account on his device. Being logged in to a Google account is mandatory for passkeys to work on Android devices.
- NoCreateOptionException
- During the create credential flow, this is thrown when no viable creation options were found for the given CreateCredentialRequest. (no passkeys providers available or none enabled)
- NoCredentialsAvailableException
- This exception is thrown when the user tries to login but does not have any credentials available for the authenticator.
- PasskeyAuthCancelledException
- Thrown when the user cancels the passkey flow.
- PasskeyUnsupportedException
- This exception is thrown when passkey-related APIs are called on an unsupported Android version (API < 28).
- SyncAccountNotAvailableException
- This exception is thrown when the passkey can not be retrieved from the entity that is used for passkey syncing. Currently this error is observed when testing on Android emulators. In these cases you need to restart the emulator using the 'Cold Boot Now' option.
- TimeoutException
- This exception is thrown when the user tries to login or register but the operation times out.
- UnhandledAuthenticatorException
- This exception is thrown when an exception is thrown by the authenticator that we do not handle so far in this package.