AuthenticatorSelectionType class

Annotations
  • @JsonSerializable.new()

Constructors

AuthenticatorSelectionType({String? authenticatorAttachment, required bool requireResidentKey, required String residentKey, required String userVerification})
Constructs a new instance.
AuthenticatorSelectionType.fromJson(Map<String, dynamic> json)
factory

Properties

authenticatorAttachment String?
final
hashCode int
The hash code for this object.
no setterinherited
requireResidentKey bool
Optional in the WebAuthn spec; defaults to false when omitted or null.
final
residentKey String
Optional in the WebAuthn spec with no static default; when omitted or null its effective value is derived from requireResidentKey ('required' when true, otherwise 'discouraged') per WebAuthn Level 3 5.4.4.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVerification String
Optional in the WebAuthn spec; defaults to 'preferred' when omitted or null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited