RegisterResponseType class

The response returned by the platform after a registration flow.

Constructors

RegisterResponseType({required String id, required String rawId, required String clientDataJSON, required String attestationObject, required List<String?> transports, Map<String?, Object?>? clientExtensionResults})
Constructs a new instance.
const
RegisterResponseType.fromJson(Map<String, dynamic> json)
Constructs a new instance from a JSON map.
factory
RegisterResponseType.fromJsonString(String jsonString)
Constructs a new instance from a JSON string.
factory

Properties

attestationObject String
The attestation object containing the credential public key.
final
clientDataJSON String
The client data JSON.
final
clientExtensionResults Map<String?, Object?>?
Raw WebAuthn client extension results, including the on-device PRF output.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The ID of the newly created credential.
final
rawId String
The raw ID of the newly created credential.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transports List<String?>
The transports supported by the authenticator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toJsonString() String
Converts this instance to a JSON string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited