SignalAllAcceptedCredentialsRequestType class

The SignalAllAcceptedCredentialsRequestType is used to tell the platform the complete set of credential IDs that the relying party still accepts for a given user, so that any others can be pruned from the credential picker.

This wraps the WebAuthn PublicKeyCredential.signalAllAcceptedCredentials() signal.

Constructors

SignalAllAcceptedCredentialsRequestType({required String relyingPartyId, required String userId, required List<String> allAcceptedCredentialIds})
Constructs a new instance.
const

Properties

allAcceptedCredentialIds List<String>
The Base64URL encoded IDs of all credentials that are still accepted by the relying party for this user.
final
hashCode int
The hash code for this object.
no setterinherited
relyingPartyId String
The relying party ID the credentials belong to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
The Base64URL encoded ID of the user the credentials belong to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited