SignalUnknownCredentialRequestType class

The SignalUnknownCredentialRequestType is used to tell the platform that a credential is no longer recognized by the relying party, so that it can be removed from the credential picker and autofill suggestions.

This wraps the WebAuthn PublicKeyCredential.signalUnknownCredential() signal.

Constructors

SignalUnknownCredentialRequestType({required String relyingPartyId, required String credentialId})
Constructs a new instance.
const

Properties

credentialId String
The Base64URL encoded ID of the credential that is no longer recognized.
final
hashCode int
The hash code for this object.
no setterinherited
relyingPartyId String
The relying party ID the credential belongs to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited