PasskeyAuthenticator class
Handles platform dependent parts of the registration and authentication flow.
- Implemented types
Constructors
- PasskeyAuthenticator({bool? debugMode})
- Constructor
Properties
- debugMode → bool
-
Indicates whether the app is in debug mode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resultStream
→ Stream<
Result> -
Returns a stream of results from the debugging doctor.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
AuthenticateRequestType request) → Future< AuthenticateResponseType> -
Authenticates a user with a passkey.
Returns AuthenticateResponseType which must be sent to the relying party
server.
override
-
canAuthenticate(
) → Future< bool> - Returns true only if passkeys are supported by the platform.
-
cancelCurrentAuthenticatorOperation(
) → Future< void> - Cancels the current authenticator operation.
-
getAvailability(
) → GetAvailability - Returns platform-specific information about the availability of passkeys.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
RegisterRequestType request) → Future< RegisterResponseType> -
Creates a new passkey and stores it on the device.
Returns RegisterResponseType which must be sent to the relying party
server.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited