AuthenticatorSelectionType class

Describes the relying party's requirements for the authenticator that should be used during a credential operation.

Annotations
  • @JsonSerializable.new()

Constructors

AuthenticatorSelectionType({required bool requireResidentKey, required String residentKey, required String userVerification, String? authenticatorAttachment})
Constructs a new instance.
AuthenticatorSelectionType.fromJson(Map<String, dynamic> json)
Constructs a new instance from a JSON map.
factory

Properties

authenticatorAttachment String?
The preferred attachment modality of the authenticator (e.g. platform or cross-platform).
final
hashCode int
The hash code for this object.
no setterinherited
requireResidentKey bool
Optional in the WebAuthn spec; defaults to false when omitted or null.
final
residentKey String
Optional in the WebAuthn spec with no static default; when omitted or null its effective value is derived from requireResidentKey ('required' when true, otherwise 'discouraged') per WebAuthn Level 3 5.4.4.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVerification String
Optional in the WebAuthn spec; defaults to 'preferred' when omitted or null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited